@@ -13,7 +13,6 @@ copyright = "2025, Abhishek Tiwari"
 author = "Abhishek Tiwari"
 
 
-
 # General configuration
 extensions = [
     "sphinx.ext.autodoc",
@@ -72,7 +71,7 @@ html_theme = "sphinx_book_theme"
 html_static_path = ["_static"]
 # Custom CSS files
 html_css_files = [
-    'custom.css',
+    "custom.css",
 ]
 html_theme_options = {
     "repository_url": "https://github.com/abhishektiwari/axioms-flask-py",
@@ -81,7 +80,7 @@ html_theme_options = {
     "path_to_docs": "docs",
     "use_issues_button": True,
     "use_repository_button": True,
-    "use_edit_page_button": True, 
+    "use_edit_page_button": True,
     "use_download_button": False,
     "use_fullscreen_button": True,
     "use_sidenotes": True,
@@ -105,8 +104,8 @@ html_theme_options = {
             "icon": "fa-brands fa-python",
             "type": "fontawesome",
         },
-   ]
+    ],
 }
 
 # Additional options
-add_module_names = False
\ No newline at end of file
+add_module_names = False
