@@ -4,6 +4,7 @@
 def test_import_axioms_flask():
     """Test that axioms_flask package can be imported after installation."""
     import axioms_flask
+
     assert axioms_flask is not None
 
 
@@ -12,7 +13,7 @@ def test_package_version():
     import axioms_flask
 
     # Check if version attribute exists (might not be defined yet)
-    if hasattr(axioms_flask, '__version__'):
+    if hasattr(axioms_flask, "__version__"):
         version = axioms_flask.__version__
         assert isinstance(version, str)
         assert len(version) > 0
@@ -25,13 +26,15 @@ def test_package_version():
 def test_import_error_module():
     """Test that error module can be imported."""
     from axioms_flask import error
+
     assert error is not None
 
     # Check that AxiomsError class exists
-    assert hasattr(error, 'AxiomsError')
+    assert hasattr(error, "AxiomsError")
 
 
 def test_import_methodview_module():
     """Test that methodview module can be imported."""
     from axioms_flask import methodview
+
     assert methodview is not None
